%global namedreltag .Final
%global namedversion %{version}%{?namedreltag}

# Use this switch to rebuild without infinispan
# This is useful to break the hibernate-search circular dependency
%define with_infinispan 1

Name:             hibernate-search
Version:          4.5.1
Release:          4%{?dist}
Summary:          Hibernate Search
License:          LGPLv2+
Url:              http://search.hibernate.org

# wget https://github.com/hibernate/hibernate-search/archive/4.5.1.Final.tar.gz
# tar -xf 4.5.1.Final.tar.gz
# rm -rf hibernate-search-4.5.1.Final/orm/src/test/resources/org/hibernate/search/test/bridge/tika/
# tar -cvjf hibernate-search-4.5.1.Final-CLEAN.tar.gz hibernate-search-4.5.1.Final/
Source0:          hibernate-search-%{namedversion}-CLEAN.tar.gz

BuildRequires:    maven-local
BuildRequires:    jboss-logging
BuildRequires:    jboss-logging-tools
BuildRequires:    avro
BuildRequires:    jgroups
BuildRequires:    slf4j
BuildRequires:    jboss-transaction-1.1-api

%if 0%{?fedora} >= 21
BuildRequires:    lucene3
BuildRequires:    lucene3-contrib
%else
BuildRequires:    lucene
BuildRequires:    lucene-contrib
%endif

BuildRequires:    solr3

BuildRequires:    h2
BuildRequires:    maven-checkstyle-plugin
BuildRequires:    maven-processor-plugin
BuildRequires:    maven-injection-plugin
BuildRequires:    byteman
BuildRequires:    hibernate-commons-annotations
BuildRequires:    hibernate-jpa-2.1-api
BuildRequires:    hibernate-core >= 4.3.1-1
BuildRequires:    geronimo-jta
BuildRequires:    junit
BuildRequires:    tika

%if %{with_infinispan}
BuildRequires:    infinispan
%endif

BuildArch:        noarch

%description
Full text search engines like Apache Lucene are very powerful technologies to
add efficient free text search capabilities to applications. However, Lucene
suffers several mismatches when dealing with object domain models. Amongst
other things indexes have to be kept up to date and mismatches between index
structure and domain model as well as query mismatches have to be avoided.

Hibernate Search addresses these shortcomings - it indexes your domain model
with the help of a few annotations, takes care of database/index
synchronization and brings back regular managed objects from free text queries.

Hibernate Search is using Apache Lucene under the cover.

%package javadoc
Summary:          Javadocs for %{name}

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n hibernate-search-%{namedversion}

%pom_disable_module integrationtest/wildfly
%pom_disable_module integrationtest/spring
%pom_disable_module integrationtest/narayana
%pom_disable_module testing
%pom_disable_module modules
%pom_disable_module legacy

%if !%{with_infinispan}
%pom_disable_module infinispan
%endif

%pom_remove_plugin ":maven-enforcer-plugin"

%pom_remove_dep "org.apache.tika:tika-parsers" engine/pom.xml
%pom_add_dep "org.apache.tika:tika-core" engine/pom.xml

sed -i "s|luceneVersion>3.6.2</luceneVersion|luceneVersion>3</luceneVersion|" pom.xml

%build
%mvn_build -f

%install
%mvn_install

%files -f .mfiles
%dir %{_javadir}/%{name}
%doc lgpl.txt README.md

%files javadoc -f .mfiles-javadoc
%doc lgpl.txt

%changelog
* Mon Jun 16 2014 Marek Goldmann <mgoldman@redhat.com> - 4.5.1-4
- Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.5.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Apr 17 2014 Marek Goldmann <mgoldman@redhat.com> - 4.5.1-2
- Rebuild with infinispan

* Wed Apr 16 2014 Marek Goldmann <mgoldman@redhat.com> - 4.5.1-1
- Upstream release 4.5.1.Final
- Add support for lucene3 compat package in Fedora > 20

* Fri Mar 28 2014 Michael Simacek <msimacek@redhat.com> - 4.5.0-2
- Use Requires: java-headless rebuild (#1067528)

* Fri Feb 14 2014 Marek Goldmann <mgoldman@redhat.com> - 4.5.0-1
- Upstream release 4.5.0.Final

* Wed Jan 15 2014 Marek Goldmann <mgoldman@redhat.com> - 4.5.0-0.1.Alpha2
- Upstream release 4.5.0.Alpha2

* Wed Oct 23 2013 Mikolaj Izdebski <mizdebsk@redhat.com> - 4.4.0-0.6.CR1
- Rebuild to regenerate broken POMs
- Related: rhbz#1021484

* Mon Oct 21 2013 Marek Goldmann <mgoldman@redhat.com> - 4.4.0-0.5.CR1
- Enable infinispan module

* Fri Oct 18 2013 Marek Goldmann <mgoldman@redhat.com> - 4.4.0-0.4.CR1
- Updated license and dist macro

* Fri Oct 18 2013 Marek Goldmann <mgoldman@redhat.com> - 4.4.0-0.3.CR1
- Cleaned up source from mp3 (?!) files

* Wed Oct 16 2013 Marek Goldmann <mgoldman@redhat.com> - 4.4.0-0.2.CR1
- Use version 3 (compat) of solr

* Wed Oct 09 2013 Marek Goldmann <mgoldman@redhat.com> - 4.4.0-0.1.CR1
- Initial import



